@@ -1,4 +1,5 @@
 # SPDX-FileCopyrightText: 2021 Dan Halbert for Adafruit Industries
+# SPDX-FileCopyrightText: 2021 James Carr
 #
 # SPDX-License-Identifier: Unlicense
 
@@ -10,3 +11,8 @@ def test_constrain():
     assert constrain(10, 1, 10) == 10
     assert constrain(0, 1, 10) == 1
     assert constrain(11, 1, 10) == 10
+
+    # Check out_min > out_max
+    assert constrain(5, 10, 0) == 5
+    assert constrain(-5, 10, 0) == 0
+    assert constrain(15, 10, 0) == 10
